/****************************************************************************
** QgsGridMakerPlugin meta object code from reading C++ file 'plugin.h'
**
** Created: Fri Nov 4 14:25:40 2005
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "plugin.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *QgsGridMakerPlugin::className() const
{
    return "QgsGridMakerPlugin";
}

QMetaObject *QgsGridMakerPlugin::metaObj = 0;
static QMetaObjectCleanUp cleanUp_QgsGridMakerPlugin( "QgsGridMakerPlugin", &QgsGridMakerPlugin::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString QgsGridMakerPlugin::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsGridMakerPlugin", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString QgsGridMakerPlugin::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsGridMakerPlugin", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* QgsGridMakerPlugin::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QObject::staticMetaObject();
    static const QUMethod slot_0 = {"initGui", 0, 0 };
    static const QUMethod slot_1 = {"run", 0, 0 };
    static const QUParameter param_slot_2[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod slot_2 = {"drawRasterLayer", 1, param_slot_2 };
    static const QUParameter param_slot_3[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In },
	{ 0, &static_QUType_QString, 0, QUParameter::In },
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod slot_3 = {"drawVectorLayer", 3, param_slot_3 };
    static const QUMethod slot_4 = {"unload", 0, 0 };
    static const QUMethod slot_5 = {"help", 0, 0 };
    static const QMetaData slot_tbl[] = {
	{ "initGui()", &slot_0, QMetaData::Public },
	{ "run()", &slot_1, QMetaData::Public },
	{ "drawRasterLayer(QString)", &slot_2, QMetaData::Public },
	{ "drawVectorLayer(QString,QString,QString)", &slot_3, QMetaData::Public },
	{ "unload()", &slot_4, QMetaData::Public },
	{ "help()", &slot_5, QMetaData::Public }
    };
    metaObj = QMetaObject::new_metaobject(
	"QgsGridMakerPlugin", parentObject,
	slot_tbl, 6,
	0, 0,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_QgsGridMakerPlugin.setMetaObject( metaObj );
    return metaObj;
}

void* QgsGridMakerPlugin::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "QgsGridMakerPlugin" ) )
	return this;
    if ( !qstrcmp( clname, "QgisPlugin" ) )
	return (QgisPlugin*)this;
    return QObject::qt_cast( clname );
}

bool QgsGridMakerPlugin::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: initGui(); break;
    case 1: run(); break;
    case 2: drawRasterLayer((QString)static_QUType_QString.get(_o+1)); break;
    case 3: drawVectorLayer((QString)static_QUType_QString.get(_o+1),(QString)static_QUType_QString.get(_o+2),(QString)static_QUType_QString.get(_o+3)); break;
    case 4: unload(); break;
    case 5: help(); break;
    default:
	return QObject::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool QgsGridMakerPlugin::qt_emit( int _id, QUObject* _o )
{
    return QObject::qt_emit(_id,_o);
}
#ifndef QT_NO_PROPERTIES

bool QgsGridMakerPlugin::qt_property( int id, int f, QVariant* v)
{
    return QObject::qt_property( id, f, v);
}

bool QgsGridMakerPlugin::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
